@@ -6,6 +6,7 @@ from byteplay import Code, opmap
 from render import Render, render_func, render_doc, get_request
 from urlroute import Route
 from decorator import decorator
+import inspect 
 
 _ROUTE = Route()
 
@@ -28,7 +29,16 @@ def _render_para_func(func):
 class RequestRoute(object):
     def __call__(self, func):
         func = _ROUTE(func)
-        return wrap_func(func)
+        if inspect.isclass(func):
+            w = {}
+            for k,v in func.__dict__.iteritems():
+                if not k.startswith("_") and inspect.isfunction(v):
+                    w[k] = wrap_func(v)
+            for k,v in w.iteritems():
+                setattr(func,k,v)
+        else:
+            func = wrap_func(func)
+        return func 
 
     def __getattr__(self, name):
         attr = getattr(_ROUTE, name)
@@ -53,5 +63,5 @@ def route_render_func(func):
     return _ROUTE(render_func(func))
 
 def route_render_doc(func):
-    return _ROUTE(route_render_doc(func))
+    return _ROUTE(render_doc(func))
 
